@@ -1,4 +1,5 @@
 """Internally used rule classes."""
+
 from __future__ import annotations
 
 import inspect
@@ -57,7 +58,7 @@ class BaseRule:
     _collection: RulesCollection | None = None
 
     @property
-    def help(self) -> str:  # noqa: A003
+    def help(self) -> str:
         """Return a help markdown string for the rule."""
         if self._help is None:
             self._help = ""
@@ -95,10 +96,11 @@ class BaseRule:
                     _logger.warning(
                         "Ignored exception from %s.%s while processing %s: %s",
                         self.__class__.__name__,
-                        method,
+                        method.__name__,
                         str(file),
                         exc,
                     )
+                    _logger.debug("Ignored exception details", exc_info=True)
         else:
             matches.extend(self.matchdir(file))
         return matches
@@ -166,7 +168,7 @@ class BaseRule:
         rule_config = self.options.rules.get(self.id, {})
         if not isinstance(rule_config, dict):  # pragma: no branch
             msg = f"Invalid rule config for {self.id}: {rule_config}"
-            raise RuntimeError(msg)
+            raise RuntimeError(msg)  # noqa: TRY004
         return rule_config
 
     @property
