@@ -1,4 +1,5 @@
 """CLI parser setup and helpers."""
+
 from __future__ import annotations
 
 import argparse
@@ -7,7 +8,7 @@ import os
 import sys
 from argparse import Namespace
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 from ansiblelint.config import (
     DEFAULT_KINDS,
@@ -16,7 +17,7 @@ from ansiblelint.config import (
     Options,
     log_entries,
 )
-from ansiblelint.constants import CUSTOM_RULESDIR_ENVVAR, DEFAULT_RULESDIR, RC
+from ansiblelint.constants import CUSTOM_RULESDIR_ENVVAR, DEFAULT_RULESDIR, EPILOG, RC
 from ansiblelint.file_utils import (
     Lintable,
     abspath,
@@ -29,7 +30,7 @@ from ansiblelint.schemas.main import validate_file_schema
 from ansiblelint.yaml_utils import clean_json
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
+    from collections.abc import Callable, Sequence
 
 
 _logger = logging.getLogger(__name__)
@@ -91,7 +92,7 @@ def load_config(config_file: str | None) -> tuple[dict[Any, Any], str | None]:
     config = clean_json(config_lintable.data)
     if not isinstance(config, dict):
         msg = "Schema failed to properly validate the config file."
-        raise RuntimeError(msg)
+        raise TypeError(msg)
     config["config_file"] = config_path
     config_dir = os.path.dirname(config_path)
     expand_to_normalized_paths(config, config_dir)
@@ -134,7 +135,7 @@ class AbspathArgAction(argparse.Action):
         values: str | Sequence[Any] | None,
         option_string: str | None = None,
     ) -> None:
-        if isinstance(values, (str, Path)):
+        if isinstance(values, str | Path):
             values = [values]
         if values:
             normalized_values = [
@@ -240,7 +241,11 @@ class WriteArgAction(argparse.Action):
 
 def get_cli_parser() -> argparse.ArgumentParser:
     """Initialize an argument parser."""
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        epilog=EPILOG,
+        # Avoid rewrapping description and epilog
+        formatter_class=argparse.RawTextHelpFormatter,
+    )
 
     listing_group = parser.add_mutually_exclusive_group()
     listing_group.add_argument(
@@ -521,8 +526,8 @@ def merge_config(file_config: dict[Any, Any], cli_config: Options) -> Options:
         v = getattr(cli_config, entry) or file_value
         setattr(cli_config, entry, v)
 
-    for entry, default in scalar_map.items():
-        file_value = file_config.pop(entry, default)
+    for entry, default_scalar in scalar_map.items():
+        file_value = file_config.pop(entry, default_scalar)
         v = getattr(cli_config, entry, None) or file_value
         setattr(cli_config, entry, v)
 
