@@ -1,4 +1,5 @@
 """Exceptions and error representations."""
+
 from __future__ import annotations
 
 import functools
@@ -6,7 +7,6 @@ from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Any
 
 from ansiblelint._internal.rules import BaseRule, RuntimeErrorRule
-from ansiblelint.config import options
 from ansiblelint.file_utils import Lintable
 
 if TYPE_CHECKING:
@@ -27,17 +27,6 @@ class WarnSource:
     message: str | None = None
 
 
-class StrictModeError(RuntimeError):
-    """Raise when we encounter a warning in strict mode."""
-
-    def __init__(
-        self,
-        message: str = "Warning treated as error due to --strict option.",
-    ):
-        """Initialize a StrictModeError instance."""
-        super().__init__(message)
-
-
 @dataclass(frozen=True)
 class RuleMatchTransformMeta:
     """Additional metadata about a match error to be used during transformation."""
@@ -110,11 +99,18 @@ class MatchError(ValueError):
             msg = "MatchError called incorrectly as column numbers start with 1"
             raise RuntimeError(msg)
 
+        self.lineno += self.lintable.line_offset
+
+        # We make the lintable aware that we found a match inside it, as this
+        # can be used to skip running other rules that do require current one
+        # to pass.
+        self.lintable.matches.append(self)
+
     @functools.cached_property
     def level(self) -> str:
         """Return the level of the rule: error, warning or notice."""
         if not self.ignored and {self.tag, self.rule.id, *self.rule.tags}.isdisjoint(
-            options.warn_list,
+            self.rule.options.warn_list,
         ):
             return "error"
         return "warning"
