@@ -1,4 +1,5 @@
 """Rule for checking content of jinja template strings."""
+
 from __future__ import annotations
 
 import logging
@@ -11,7 +12,7 @@ from typing import TYPE_CHECKING, Any, NamedTuple
 
 import black
 import jinja2
-from ansible.errors import AnsibleError, AnsibleParserError
+from ansible.errors import AnsibleError, AnsibleFilterError, AnsibleParserError
 from ansible.parsing.yaml.objects import AnsibleUnicode
 from jinja2.exceptions import TemplateSyntaxError
 
@@ -132,6 +133,8 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                             variables=deannotate(task.get("vars", {})),
                             fail_on_error=True,  # we later decide which ones to ignore or not
                         )
+                    except AnsibleFilterError:
+                        bypass = True
                     # ValueError RepresenterError
                     except AnsibleError as exc:
                         bypass = False
@@ -144,7 +147,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                         )
                         if ignored_re.search(orig_exc_message) or isinstance(
                             orig_exc,
-                            (AnsibleParserError, TypeError),
+                            AnsibleParserError | TypeError,
                         ):
                             # An unhandled exception occurred while running the lookup plugin 'template'. Error was a <class 'ansible.errors.AnsibleError'>, original message: the template file ... could not be found for the lookup. the template file ... could not be found for the lookup
 
@@ -152,7 +155,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                             # AnsibleError(TemplateSyntaxError): template error while templating string: Could not load "ipwrap": 'Invalid plugin FQCN (ansible.netcommon.ipwrap): unable to locate collection ansible.netcommon'. String: Foo {{ buildset_registry.host | ipwrap }}. Could not load "ipwrap": 'Invalid plugin FQCN (ansible.netcommon.ipwrap): unable to locate collection ansible.netcommon'
                             bypass = True
                         elif (
-                            isinstance(orig_exc, (AnsibleError, TemplateSyntaxError))
+                            isinstance(orig_exc, AnsibleError | TemplateSyntaxError)
                             and match
                         ):
                             error = match.group("error")
@@ -365,7 +368,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                     # process expression
                     # pylint: disable=unsupported-membership-test
                     if isinstance(expr_str, str) and "\n" in expr_str:
-                        raise NotImplementedError
+                        raise NotImplementedError  # noqa: TRY301
                     leading_spaces = " " * (len(expr_str) - len(expr_str.lstrip()))
                     expr_str = leading_spaces + blacken(expr_str.lstrip())
                     if tokens[
@@ -386,6 +389,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
 
         except jinja2.exceptions.TemplateSyntaxError as exc:
             return "", str(exc.message), "invalid"
+        # pylint: disable=c-extension-no-member
         except (NotImplementedError, black.parsing.InvalidInput) as exc:
             # black is not able to recognize all valid jinja2 templates, so we
             # just ignore InvalidInput errors.
@@ -457,7 +461,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                         obj = obj[pth]
                     except (KeyError, TypeError) as exc:
                         err = f"Unable to transform {match.transform_meta}: {exc}"
-                        _logger.error(err)
+                        _logger.error(err)  # noqa: TRY400
                         return
                 try:
                     obj[path[-1]][key] = match.transform_meta.fixed
@@ -465,7 +469,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
 
                 except (KeyError, TypeError) as exc:
                     err = f"Unable to transform {match.transform_meta}: {exc}"
-                    _logger.error(err)
+                    _logger.error(err)  # noqa: TRY400
                 return
 
 
@@ -870,5 +874,5 @@ def _get_error_line(task: dict[str, Any], path: list[str | int]) -> int:
             line = ctx[LINE_NUMBER_KEY]
     if not isinstance(line, int):
         msg = "Line number is not an integer"
-        raise RuntimeError(msg)
+        raise TypeError(msg)
     return line
