@@ -1,4 +1,5 @@
 """Runner implementation."""
+
 from __future__ import annotations
 
 import json
@@ -26,10 +27,6 @@ from ansible_compat.runtime import AnsibleWarning
 
 import ansiblelint.skip_utils
 import ansiblelint.utils
-from ansiblelint._internal.rules import (
-    BaseRule,
-    LoadingFailureRule,
-)
 from ansiblelint.app import App, get_app
 from ansiblelint.constants import States
 from ansiblelint.errors import LintWarning, MatchError, WarnSource
@@ -39,17 +36,15 @@ from ansiblelint.rules.syntax_check import OUTPUT_PATTERNS
 from ansiblelint.text import strip_ansi_escape
 from ansiblelint.utils import (
     PLAYBOOK_DIR,
-    _include_children,
-    _roles_children,
-    _taskshandlers_children,
+    HandleChildren,
     parse_examples_from_plugin,
     template,
 )
 
 if TYPE_CHECKING:
-    from collections.abc import Generator
-    from typing import Callable
+    from collections.abc import Callable, Generator
 
+    from ansiblelint._internal.rules import BaseRule
     from ansiblelint.config import Options
     from ansiblelint.constants import FileType
     from ansiblelint.rules import RulesCollection
@@ -111,6 +106,8 @@ class Runner:
             checked_files = set()
         self.checked_files = checked_files
 
+        self.app = get_app(cached=True)
+
     def _update_exclude_paths(self, exclude_paths: list[str]) -> None:
         if exclude_paths:
             # These will be (potentially) relative paths
@@ -184,9 +181,9 @@ class Runner:
                     else:
                         filename = warn.source
                         match = MatchError(
-                            message=warn.message
-                            if isinstance(warn.message, str)
-                            else "?",
+                            message=(
+                                warn.message if isinstance(warn.message, str) else "?"
+                            ),
                             rule=self.rules["warning"],
                             filename=str(filename),
                         )
@@ -237,12 +234,12 @@ class Runner:
 
         # -- phase 1 : syntax check in parallel --
         if not self.skip_ansible_syntax_check:
-            app = get_app(offline=True)
+            # app = get_app(cached=True)
 
             def worker(lintable: Lintable) -> list[MatchError]:
                 return self._get_ansible_syntax_check_matches(
                     lintable=lintable,
-                    app=app,
+                    app=self.app,
                 )
 
             for lintable in self.lintables:
@@ -265,28 +262,28 @@ class Runner:
                 matches.extend(data)
 
             matches = self._filter_excluded_matches(matches)
+
         # -- phase 2 ---
-        if not matches:
-            # do our processing only when ansible syntax check passed in order
-            # to avoid causing runtime exceptions. Our processing is not as
-            # resilient to be able process garbage.
-            matches.extend(self._emit_matches(files))
+        # do our processing only when ansible syntax check passed in order
+        # to avoid causing runtime exceptions. Our processing is not as
+        # resilient to be able process garbage.
+        matches.extend(self._emit_matches(files))
 
-            # remove duplicates from files list
-            files = [value for n, value in enumerate(files) if value not in files[:n]]
+        # remove duplicates from files list
+        files = [value for n, value in enumerate(files) if value not in files[:n]]
 
-            for file in self.lintables:
-                if file in self.checked_files or not file.kind:
-                    continue
-                _logger.debug(
-                    "Examining %s of type %s",
-                    ansiblelint.file_utils.normpath(file.path),
-                    file.kind,
-                )
+        for file in self.lintables:
+            if file in self.checked_files or not file.kind or file.failed():
+                continue
+            _logger.debug(
+                "Examining %s of type %s",
+                ansiblelint.file_utils.normpath(file.path),
+                file.kind,
+            )
 
-                matches.extend(
-                    self.rules.run(file, tags=set(self.tags), skip_list=self.skip_list),
-                )
+            matches.extend(
+                self.rules.run(file, tags=set(self.tags), skip_list=self.skip_list),
+            )
 
         # update list of checked files
         self.checked_files.update(self.lintables)
@@ -372,6 +369,7 @@ class Runner:
             filename = lintable
             lineno = 1
             column = None
+            ignore_rc = False
 
             stderr = strip_ansi_escape(run.stderr)
             stdout = strip_ansi_escape(run.stdout)
@@ -391,24 +389,39 @@ class Runner:
                     details = groups.get("details", "")
                     lineno = int(groups.get("line", 1))
 
-                    if "filename" in groups:
+                    if (
+                        "filename" in groups
+                        and str(lintable.path.absolute()) != groups["filename"]
+                        and lintable.filename != groups["filename"]
+                    ):
+                        # avoids creating a new lintable object if the filename
+                        # is matching as this might prevent Lintable.failed()
+                        # feature from working well.
                         filename = Lintable(groups["filename"])
                     else:
                         filename = lintable
                     column = int(groups.get("column", 1))
-                    results.append(
-                        MatchError(
-                            message=title,
-                            lintable=filename,
-                            lineno=lineno,
-                            column=column,
-                            rule=rule,
-                            details=details,
-                            tag=f"{rule.id}[{pattern.tag}]",
-                        ),
-                    )
 
-            if not results:
+                    if (
+                        pattern.tag in ("unknown-module", "specific")
+                        and app.options.nodeps
+                    ):
+                        ignore_rc = True
+                    else:
+                        results.append(
+                            MatchError(
+                                message=title,
+                                lintable=filename,
+                                lineno=lineno,
+                                column=column,
+                                rule=rule,
+                                details=details,
+                                tag=f"{rule.id}[{pattern.tag}]",
+                            ),
+                        )
+                    break
+
+            if not results and not ignore_rc:
                 rule = self.rules["internal-error"]
                 message = (
                     f"Unexpected error code {run.returncode} from "
@@ -452,7 +465,7 @@ class Runner:
                 except MatchError as exc:
                     if not exc.filename:  # pragma: no branch
                         exc.filename = str(lintable.path)
-                    exc.rule = LoadingFailureRule()
+                    exc.rule = self.rules["load-failure"]
                     yield exc
                 except AttributeError:
                     yield MatchError(lintable=lintable, rule=self.rules["load-failure"])
@@ -475,7 +488,10 @@ class Runner:
             try:
                 playbook_ds = ansiblelint.utils.parse_yaml_from_file(str(lintable.path))
             except AnsibleError as exc:
-                raise SystemExit(exc) from exc
+                msg = f"Loading {lintable.filename} caused an {type(exc).__name__} exception: {exc}, file was ignored."
+                logging.exception(msg)
+                # raise SystemExit(exc) from exc
+                return []
         results = []
         # playbook_ds can be an AnsibleUnicode string, which we consider invalid
         if isinstance(playbook_ds, str):
@@ -504,7 +520,6 @@ class Runner:
                 if path != path_str:
                     child.path = Path(path)
                     child.name = child.path.name
-
                 results.append(child)
         return results
 
@@ -517,22 +532,28 @@ class Runner:
     ) -> list[Lintable]:
         """Flatten the traversed play tasks."""
         # pylint: disable=unused-argument
-        delegate_map: dict[str, Callable[[str, Any, Any, FileType], list[Lintable]]] = {
-            "tasks": _taskshandlers_children,
-            "pre_tasks": _taskshandlers_children,
-            "post_tasks": _taskshandlers_children,
-            "block": _taskshandlers_children,
-            "include": _include_children,
-            "ansible.builtin.include": _include_children,
-            "import_playbook": _include_children,
-            "ansible.builtin.import_playbook": _include_children,
-            "roles": _roles_children,
-            "dependencies": _roles_children,
-            "handlers": _taskshandlers_children,
-            "include_tasks": _include_children,
-            "ansible.builtin.include_tasks": _include_children,
-            "import_tasks": _include_children,
-            "ansible.builtin.import_tasks": _include_children,
+
+        handlers = HandleChildren(self.rules, app=self.app)
+
+        delegate_map: dict[
+            str,
+            Callable[[str, Any, Any, FileType], list[Lintable]],
+        ] = {
+            "tasks": handlers.taskshandlers_children,
+            "pre_tasks": handlers.taskshandlers_children,
+            "post_tasks": handlers.taskshandlers_children,
+            "block": handlers.taskshandlers_children,
+            "include": handlers.include_children,
+            "ansible.builtin.include": handlers.include_children,
+            "import_playbook": handlers.include_children,
+            "ansible.builtin.import_playbook": handlers.include_children,
+            "roles": handlers.roles_children,
+            "dependencies": handlers.roles_children,
+            "handlers": handlers.taskshandlers_children,
+            "include_tasks": handlers.include_children,
+            "ansible.builtin.include_tasks": handlers.include_children,
+            "import_tasks": handlers.include_children,
+            "ansible.builtin.import_tasks": handlers.include_children,
         }
         (k, v) = item
         add_all_plugin_dirs(str(basedir.resolve()))
