@@ -28,11 +28,11 @@ import inspect
 import logging
 import os
 import re
-from collections.abc import Generator, ItemsView, Iterator, Mapping, Sequence
+from collections.abc import ItemsView, Iterator, Mapping, Sequence
 from dataclasses import _MISSING_TYPE, dataclass, field
-from functools import cache
+from functools import cache, lru_cache
 from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import ruamel.yaml.parser
 import yaml
@@ -44,7 +44,12 @@ from ansible.parsing.plugin_docs import read_docstring
 from ansible.parsing.yaml.constructor import AnsibleConstructor, AnsibleMapping
 from ansible.parsing.yaml.loader import AnsibleLoader
 from ansible.parsing.yaml.objects import AnsibleBaseYAMLObject, AnsibleSequence
-from ansible.plugins.loader import add_all_plugin_dirs
+from ansible.plugins.loader import (
+    PluginLoadContext,
+    action_loader,
+    add_all_plugin_dirs,
+    module_loader,
+)
 from ansible.template import Templar
 from ansible.utils.collection_loader import AnsibleCollectionConfig
 from yaml.composer import Composer
@@ -54,7 +59,7 @@ from ansiblelint._internal.rules import (
     AnsibleParserErrorRule,
     RuntimeErrorRule,
 )
-from ansiblelint.app import get_app
+from ansiblelint.app import App, get_app
 from ansiblelint.config import Options, options
 from ansiblelint.constants import (
     ANNOTATION_KEYS,
@@ -72,6 +77,8 @@ from ansiblelint.file_utils import Lintable, discover_lintables
 from ansiblelint.skip_utils import is_nested_task
 from ansiblelint.text import has_jinja, removeprefix
 
+if TYPE_CHECKING:
+    from ansiblelint.rules import RulesCollection
 # ansible-lint doesn't need/want to know about encrypted secrets, so we pass a
 # string as the password to enable such yaml files to be opened and parsed
 # successfully.
@@ -167,7 +174,6 @@ def ansible_template(
     for _i in range(10):
         try:
             templated = templar.template(varname, **kwargs)
-            return templated
         except AnsibleError as exc:
             if lookup_error in exc.message:
                 return varname
@@ -189,15 +195,14 @@ def ansible_template(
                     _logger.warning(err)
                     raise
 
-                templar.environment.filters._delegatee[  # noqa: SLF001
-                    missing_filter
-                ] = mock_filter
+                templar.environment.filters._delegatee[missing_filter] = mock_filter  # fmt: skip # noqa: SLF001
                 # Record the mocked filter so we can warn the user
                 if missing_filter not in options.mock_filters:
                     _logger.debug("Mocking missing filter %s", missing_filter)
                     options.mock_filters.append(missing_filter)
                 continue
             raise
+        return templated
     return None
 
 
@@ -280,110 +285,175 @@ def template(
     return value
 
 
-def _include_children(
-    basedir: str,
-    k: str,
-    v: Any,
-    parent_type: FileType,
-) -> list[Lintable]:
-    # handle special case include_tasks: name=filename.yml
-    if k in INCLUSION_ACTION_NAMES and isinstance(v, dict) and "file" in v:
-        v = v["file"]
+@dataclass
+class HandleChildren:
+    """Parse task, roles and children."""
 
-    # we cannot really parse any jinja2 in includes, so we ignore them
-    if not v or "{{" in v:
-        return []
+    rules: RulesCollection = field(init=True, repr=False)
+    app: App
 
-    if "import_playbook" in k and COLLECTION_PLAY_RE.match(v):
-        # Any import_playbooks from collections should be ignored as ansible
-        # own syntax check will handle them.
-        return []
+    def include_children(
+        self,
+        basedir: str,
+        k: str,
+        v: Any,
+        parent_type: FileType,
+    ) -> list[Lintable]:
+        """Include children."""
+        # handle special case include_tasks: name=filename.yml
+        if k in INCLUSION_ACTION_NAMES and isinstance(v, dict) and "file" in v:
+            v = v["file"]
 
-    # handle include: filename.yml tags=blah
-    # pylint: disable=unused-variable
-    (command, args, kwargs) = tokenize(f"{k}: {v}")
+        # we cannot really parse any jinja2 in includes, so we ignore them
+        if not v or "{{" in v:
+            return []
+
+        if k in ("import_playbook", "ansible.builtin.import_playbook"):
+            included = Path(basedir) / v
+            if self.app.runtime.has_playbook(v, basedir=Path(basedir)):
+                if included.exists():
+                    return [Lintable(included, kind=parent_type)]
+                return []
+            msg = f"Failed to find {v} playbook."
+            logging.error(msg)
+            return []
+
+        # handle include: filename.yml tags=blah
+        # pylint: disable=unused-variable
+        (command, args, kwargs) = tokenize(f"{k}: {v}")
 
-    result = path_dwim(basedir, args[0])
-    while basedir not in ["", "/"]:
-        if os.path.exists(result):
-            break
-        basedir = os.path.dirname(basedir)
         result = path_dwim(basedir, args[0])
+        while basedir not in ["", "/"]:
+            if os.path.exists(result):
+                break
+            basedir = os.path.dirname(basedir)
+            result = path_dwim(basedir, args[0])
 
-    return [Lintable(result, kind=parent_type)]
+        return [Lintable(result, kind=parent_type)]
 
-
-def _taskshandlers_children(
-    basedir: str,
-    k: str,
-    v: None | Any,
-    parent_type: FileType,
-) -> list[Lintable]:
-    results: list[Lintable] = []
-    if v is None:
-        raise MatchError(
-            message="A malformed block was encountered while loading a block.",
-            rule=RuntimeErrorRule(),
-        )
-    for task_handler in v:
-        # ignore empty tasks, `-`
-        if not task_handler:
-            continue
-
-        with contextlib.suppress(LookupError):
-            children = _get_task_handler_children_for_tasks_or_playbooks(
-                task_handler,
-                basedir,
-                k,
-                parent_type,
+    def taskshandlers_children(
+        self,
+        basedir: str,
+        k: str,
+        v: None | Any,
+        parent_type: FileType,
+    ) -> list[Lintable]:
+        """TasksHandlers Children."""
+        results: list[Lintable] = []
+        if v is None or isinstance(v, int | str):
+            raise MatchError(
+                message="A malformed block was encountered while loading a block.",
+                rule=RuntimeErrorRule(),
             )
-            results.append(children)
-            continue
-
-        if any(x in task_handler for x in ROLE_IMPORT_ACTION_NAMES):
-            task_handler = normalize_task_v2(task_handler)
-            _validate_task_handler_action_for_role(task_handler["action"])
-            name = task_handler["action"].get("name")
-            if has_jinja(name):
-                # we cannot deal with dynamic imports
+        for task_handler in v:
+            # ignore empty tasks, `-`
+            if not task_handler:
                 continue
-            results.extend(
-                _roles_children(
+
+            with contextlib.suppress(LookupError):
+                children = _get_task_handler_children_for_tasks_or_playbooks(
+                    task_handler,
                     basedir,
                     k,
-                    [name],
                     parent_type,
-                    main=task_handler["action"].get("tasks_from", "main"),
-                ),
-            )
-            continue
+                )
+                results.append(children)
+                continue
 
-        if "block" not in task_handler:
-            continue
+            if any(x in task_handler for x in ROLE_IMPORT_ACTION_NAMES):
+                task_handler = normalize_task_v2(task_handler)
+                self._validate_task_handler_action_for_role(task_handler["action"])
+                name = task_handler["action"].get("name")
+                if has_jinja(name):
+                    # we cannot deal with dynamic imports
+                    continue
+                results.extend(
+                    self.roles_children(basedir, k, [name], parent_type),
+                )
+                continue
+
+            if "block" not in task_handler:
+                continue
 
-        results.extend(
-            _taskshandlers_children(basedir, k, task_handler["block"], parent_type),
-        )
-        if "rescue" in task_handler:
             results.extend(
-                _taskshandlers_children(
+                self.taskshandlers_children(
                     basedir,
                     k,
-                    task_handler["rescue"],
+                    task_handler["block"],
                     parent_type,
                 ),
             )
-        if "always" in task_handler:
-            results.extend(
-                _taskshandlers_children(
-                    basedir,
-                    k,
-                    task_handler["always"],
-                    parent_type,
+            if "rescue" in task_handler:
+                results.extend(
+                    self.taskshandlers_children(
+                        basedir,
+                        k,
+                        task_handler["rescue"],
+                        parent_type,
+                    ),
+                )
+            if "always" in task_handler:
+                results.extend(
+                    self.taskshandlers_children(
+                        basedir,
+                        k,
+                        task_handler["always"],
+                        parent_type,
+                    ),
+                )
+
+        return results
+
+    def _validate_task_handler_action_for_role(self, th_action: dict[str, Any]) -> None:
+        """Verify that the task handler action is valid for role include."""
+        module = th_action["__ansible_module__"]
+
+        if "name" not in th_action:
+            raise MatchError(
+                message=f"Failed to find required 'name' key in {module!s}",
+                rule=self.rules.rules[0],
+                filename=(
+                    self.rules.options.lintables[0]
+                    if self.rules.options.lintables
+                    else "."
                 ),
             )
 
-    return results
+        if not isinstance(th_action["name"], str):
+            raise MatchError(
+                message=f"Value assigned to 'name' key on '{module!s}' is not a string.",
+                rule=self.rules.rules[1],
+            )
+
+    def roles_children(
+        self,
+        basedir: str,
+        k: str,
+        v: Sequence[Any],
+        parent_type: FileType,
+    ) -> list[Lintable]:
+        """Roles children."""
+        # pylint: disable=unused-argument # parent_type)
+        results: list[Lintable] = []
+        if not v:
+            # typing does not prevent junk from being passed in
+            return results
+        for role in v:
+            if isinstance(role, dict):
+                if "role" in role or "name" in role:
+                    if "tags" not in role or "skip_ansible_lint" not in role["tags"]:
+                        results.extend(
+                            _look_for_role_files(
+                                basedir,
+                                role.get("role", role.get("name")),
+                            ),
+                        )
+                elif k != "dependencies":
+                    msg = f'role dict {role} does not contain a "role" or "name" key'
+                    raise SystemExit(msg)
+            else:
+                results.extend(_look_for_role_files(basedir, role))
+        return results
 
 
 def _get_task_handler_children_for_tasks_or_playbooks(
@@ -399,7 +469,7 @@ def _get_task_handler_children_for_tasks_or_playbooks(
     for task_handler_key in INCLUSION_ACTION_NAMES:
         with contextlib.suppress(KeyError):
             # ignore empty tasks
-            if not task_handler:  # pragma: no branch
+            if not task_handler or isinstance(task_handler, str):  # pragma: no branch
                 continue
 
             file_name = task_handler[task_handler_key]
@@ -417,50 +487,6 @@ def _get_task_handler_children_for_tasks_or_playbooks(
     raise LookupError(msg)
 
 
-def _validate_task_handler_action_for_role(th_action: dict[str, Any]) -> None:
-    """Verify that the task handler action is valid for role include."""
-    module = th_action["__ansible_module__"]
-
-    if "name" not in th_action:
-        raise MatchError(message=f"Failed to find required 'name' key in {module!s}")
-
-    if not isinstance(th_action["name"], str):
-        raise MatchError(
-            message=f"Value assigned to 'name' key on '{module!s}' is not a string.",
-        )
-
-
-def _roles_children(
-    basedir: str,
-    k: str,
-    v: Sequence[Any],
-    parent_type: FileType,  # noqa: ARG001
-    main: str = "main",
-) -> list[Lintable]:
-    # pylint: disable=unused-argument # parent_type)
-    results: list[Lintable] = []
-    if not v:
-        # typing does not prevent junk from being passed in
-        return results
-    for role in v:
-        if isinstance(role, dict):
-            if "role" in role or "name" in role:
-                if "tags" not in role or "skip_ansible_lint" not in role["tags"]:
-                    results.extend(
-                        _look_for_role_files(
-                            basedir,
-                            role.get("role", role.get("name")),
-                            main=main,
-                        ),
-                    )
-            elif k != "dependencies":
-                msg = f'role dict {role} does not contain a "role" or "name" key'
-                raise SystemExit(msg)
-        else:
-            results.extend(_look_for_role_files(basedir, role, main=main))
-    return results
-
-
 def _rolepath(basedir: str, role: str) -> str | None:
     role_path = None
 
@@ -475,7 +501,7 @@ def _rolepath(basedir: str, role: str) -> str | None:
         path_dwim(basedir, os.path.join("..", role)),
     ]
 
-    for loc in get_app(offline=True).runtime.config.default_roles_path:
+    for loc in get_app(cached=True).runtime.config.default_roles_path:
         loc = os.path.expanduser(loc)
         possible_paths.append(path_dwim(loc, role))
 
@@ -492,12 +518,7 @@ def _rolepath(basedir: str, role: str) -> str | None:
     return role_path
 
 
-def _look_for_role_files(
-    basedir: str,
-    role: str,
-    main: str | None = "main",  # noqa: ARG001
-) -> list[Lintable]:
-    # pylint: disable=unused-argument # main
+def _look_for_role_files(basedir: str, role: str) -> list[Lintable]:
     role_path = _rolepath(basedir, role)
     if not role_path:  # pragma: no branch
         return []
@@ -588,7 +609,7 @@ def normalize_task_v2(task: dict[str, Any]) -> dict[str, Any]:
 
     if not isinstance(action, str):
         msg = f"Task actions can only be strings, got {action}"
-        raise RuntimeError(msg)
+        raise TypeError(msg)
     action_unnormalized = action
     # convert builtin fqn calls to short forms because most rules know only
     # about short calls but in the future we may switch the normalization to do
@@ -715,7 +736,7 @@ class Task(dict[str, Any]):
         action_name = self.normalized_task["action"]["__ansible_module_original__"]
         if not isinstance(action_name, str):
             msg = "Task actions can only be strings."
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         return action_name
 
     @property
@@ -749,7 +770,7 @@ class Task(dict[str, Any]):
                 self._normalized_task = self.raw_task
         if isinstance(self._normalized_task, _MISSING_TYPE):
             msg = "Task was not normalized"
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         return self._normalized_task
 
     @property
@@ -779,7 +800,7 @@ class Task(dict[str, Any]):
         """Allow access as task[...]."""
         return self.normalized_task[index]
 
-    def __iter__(self) -> Generator[str, None, None]:
+    def __iter__(self) -> Iterator[str]:
         """Provide support for 'key in task'."""
         yield from (f for f in self.normalized_task)
 
@@ -875,7 +896,7 @@ def parse_yaml_linenumbers(
         node = Composer.compose_node(loader, parent, index)
         if not isinstance(node, yaml.nodes.Node):
             msg = "Unexpected yaml data."
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         node.__line__ = line + 1  # type: ignore[attr-defined]
         return node
 
@@ -1056,3 +1077,27 @@ def parse_examples_from_plugin(lintable: Lintable) -> tuple[int, str]:
     # Ignore the leading newline and lack of document start
     # as including those in EXAMPLES would be weird.
     return offset, (f"---{examples}" if examples else "")
+
+
+@lru_cache
+def load_plugin(name: str) -> PluginLoadContext:
+    """Return loaded ansible plugin/module."""
+    loaded_module = action_loader.find_plugin_with_context(
+        name,
+        ignore_deprecated=True,
+        check_aliases=True,
+    )
+    if not loaded_module.resolved:
+        loaded_module = module_loader.find_plugin_with_context(
+            name,
+            ignore_deprecated=True,
+            check_aliases=True,
+        )
+    if not loaded_module.resolved and name.startswith("ansible.builtin."):
+        # fallback to core behavior of using legacy
+        loaded_module = module_loader.find_plugin_with_context(
+            name.replace("ansible.builtin.", "ansible.legacy."),
+            ignore_deprecated=True,
+            check_aliases=True,
+        )
+    return loaded_module
