@@ -23,7 +23,7 @@ from ruamel.yaml.emitter import Emitter, ScalarAnalysis
 # To make the type checkers happy, we import from ruamel.yaml.main instead.
 from ruamel.yaml.main import YAML
 from ruamel.yaml.parser import ParserError
-from ruamel.yaml.scalarint import ScalarInt
+from ruamel.yaml.scalarint import HexInt, ScalarInt
 from yamllint.config import YamlLintConfig
 
 from ansiblelint.constants import (
@@ -46,28 +46,17 @@ if TYPE_CHECKING:
 _logger = logging.getLogger(__name__)
 
 
-YAMLLINT_CONFIG = """
-extends: default
-rules:
-  comments:
-    # https://github.com/prettier/prettier/issues/6780
-    min-spaces-from-content: 1
-  # https://github.com/adrienverge/yamllint/issues/384
-  comments-indentation: false
-  document-start: disable
-  # 160 chars was the default used by old E204 rule, but
-  # you can easily change it or disable in your .yamllint file.
-  line-length:
-    max: 160
-  # We are adding an extra space inside braces as that's how prettier does it
-  # and we are trying not to fight other linters.
-  braces:
-    min-spaces-inside: 0  # yamllint defaults to 0
-    max-spaces-inside: 1  # yamllint defaults to 0
-  octal-values:
-    forbid-implicit-octal: true  # yamllint defaults to false
-    forbid-explicit-octal: true  # yamllint defaults to false
-"""
+class CustomYamlLintConfig(YamlLintConfig):  # type: ignore[misc]
+    """Extension of YamlLintConfig."""
+
+    def __init__(
+        self,
+        content: str | None = None,
+        file: str | Path | None = None,
+    ) -> None:
+        """Initialize config."""
+        super().__init__(content, file)
+        self.incompatible = ""
 
 
 def deannotate(data: Any) -> Any:
@@ -85,10 +74,10 @@ def deannotate(data: Any) -> Any:
     return data
 
 
-@functools.lru_cache(maxsize=1)
-def load_yamllint_config() -> YamlLintConfig:
+def load_yamllint_config() -> CustomYamlLintConfig:
     """Load our default yamllint config and any customized override file."""
-    config = YamlLintConfig(content=YAMLLINT_CONFIG)
+    config = CustomYamlLintConfig(file=Path(__file__).parent / "data" / ".yamllint")
+    config.incompatible = ""
     # if we detect local yamllint config we use it but raise a warning
     # as this is likely to get out of sync with our internal config.
     for path in [
@@ -105,10 +94,65 @@ def load_yamllint_config() -> YamlLintConfig:
                 "internal yamllint config.",
                 file,
             )
-            config_override = YamlLintConfig(file=str(file))
-            config_override.extend(config)
-            config = config_override
+            custom_config = CustomYamlLintConfig(file=str(file))
+            custom_config.extend(config)
+            config = custom_config
             break
+
+    # Look for settings incompatible with our reformatting
+    checks: list[tuple[str, str | int | bool]] = [
+        (
+            "comments.min-spaces-from-content",
+            1,
+        ),
+        (
+            "comments-indentation",
+            False,
+        ),
+        (
+            "braces.min-spaces-inside",
+            0,
+        ),
+        (
+            "braces.max-spaces-inside",
+            1,
+        ),
+        (
+            "octal-values.forbid-implicit-octal",
+            True,
+        ),
+        (
+            "octal-values.forbid-explicit-octal",
+            True,
+        ),
+        # (
+        #     "key-duplicates.forbid-duplicated-merge-keys", # v1.34.0+
+        #     True,
+        # ),
+        # (
+        #   "quoted-strings.quote-type", "double",
+        # ),
+        # (
+        #   "quoted-strings.required", "only-when-needed",
+        # ),
+    ]
+    errors = []
+    for setting, expected_value in checks:
+        v = config.rules
+        for key in setting.split("."):
+            if not isinstance(v, dict):  # pragma: no cover
+                break
+            if key not in v:  # pragma: no cover
+                break
+            v = v[key]
+        if v != expected_value:
+            msg = f"{setting} must be {str(expected_value).lower()}"
+            errors.append(msg)
+    if errors:
+        nl = "\n"
+        msg = f"Found incompatible custom yamllint configuration ({file}), please either remove the file or edit it to comply with:{nl}  - {(nl + '  - ').join(errors)}.{nl}{nl}Read https://ansible.readthedocs.io/projects/lint/rules/yaml/ for more details regarding why we have these requirements. Fix mode will not be available."
+        config.incompatible = msg
+
     _logger.debug("Effective yamllint rules used: %s", config.rules)
     return config
 
@@ -253,7 +297,7 @@ def get_path_to_play(
         lc = play.lc
         if not isinstance(lc.line, int):
             msg = f"expected lc.line to be an int, got {lc.line!r}"
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         if lc.line == line_index:
             return [play_index]
         if play_index > 0 and prev_play_line_index < line_index < lc.line:
@@ -390,7 +434,7 @@ def _get_path_to_task_in_tasks_block(
 
         if not isinstance(task.lc.line, int):
             msg = f"expected task.lc.line to be an int, got {task.lc.line!r}"
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         if task.lc.line == line_index:
             return [task_index]
         if task_index > 0 and prev_task_line_index < line_index < task.lc.line:
@@ -508,7 +552,9 @@ class CustomConstructor(RoundTripConstructor):
             value_s = value_su.replace("_", "")
             if value_s[0] in "+-":
                 value_s = value_s[1:]
-            if value_s[0] == "0":
+            if value_s[0:2] == "0x":
+                ret = HexInt(ret, width=len(value_s) - 2)
+            elif value_s[0] == "0":
                 # got an octal in YAML 1.1
                 ret = OctalIntYAML11(
                     ret,
@@ -597,6 +643,9 @@ class FormattedEmitter(Emitter):
             and len(self.event.value) > 1
         ):
             if self.event.tag == "tag:yaml.org,2002:int" and self.event.implicit[0]:
+                if self.event.value.startswith("0x"):
+                    self.event.tag = "tag:yaml.org,2002:str"
+                    return ""
                 # ensures that "0123" string does not lose its quoting
                 self.event.tag = "tag:yaml.org,2002:str"
                 self.event.implicit = (True, True, True)
@@ -972,7 +1021,9 @@ class FormattedYAML(YAML):
             data = self.load_all(stream=text)
         except ParserError:
             data = None
-            _logger.error("Invalid yaml, verify the file contents and try again.")
+            _logger.error(  # noqa: TRY400
+                "Invalid yaml, verify the file contents and try again.",
+            )
         if preamble_comment is not None and isinstance(
             data,
             CommentedMap | CommentedSeq,
